@@ -116,7 +116,7 @@ impl Rational {
     /// # use rational::Rational;
     /// let mut r = Rational::new(4, 5);
     /// r.set_numerator(10);
-    /// assert_eq!(r, Rational::new(2, 1));
+    /// assert_eq!(r, Rational::new(2, 1)); // 10/5 reduces to 2/1
     /// ```
     pub fn set_numerator(&mut self, numerator: i128) {
         self.numerator = numerator;
@@ -210,6 +210,27 @@ impl Rational {
         Some(Self::new::<i128, i128>(numerator, denominator))
     }
 
+    /// Raises self to the power of `exp`.
+    ///
+    /// Unlike the `pow` methods in `std`, this supports negative exponents, returning the inverse of the result.
+    /// The exponent still needs to be an integer, since a rational number raised to the power of another rational number may be irrational.
+    ///
+    /// ## Example
+    /// ```rust
+    /// # use rational::*;
+    /// assert_eq!(Rational::new(2, 3).pow(2), Rational::new(4, 9));
+    /// assert_eq!(Rational::new(1, 4).pow(-2), Rational::new(16, 1));
+    /// ```
+    pub fn pow(self, exp: i32) -> Rational {
+        let abs = exp.abs() as u32;
+        let result = Rational::new(self.numerator().pow(abs), self.denominator().pow(abs));
+        if exp.is_negative() {
+            result.inverse()
+        } else {
+            result
+        }
+    }
+
     /// Returns `true` if `self` is an integer.
     /// This is a shorthand for `self.denominator() == 1`.
     ///
@@ -238,20 +259,23 @@ impl Rational {
 
     /// Returns a tuple representing `self` as a [mixed fraction](https://en.wikipedia.org/wiki/Fraction#Mixed_numbers).
     ///
+    /// ## Notes
+    /// The result is a tuple `(whole: i128, fraction: Rational)`, such that `whole + fraction == self`. 
+    /// This means that while you might write -7/2 as a mixed fraction: -3½, the result will be a tuple (-3, -1/2).
+    ///
     /// ## Example
     /// ```rust
     /// # use rational::*;
     /// assert_eq!(Rational::new(7, 3).mixed_fraction(), (2, Rational::new(1, 3)));
-    /// // the fractional part is always positive:
-    /// assert_eq!(Rational::new(-3, 2).mixed_fraction(), (-1, Rational::new(1, 2)));
+    /// let (mixed, fract) = Rational::new(-7, 2).mixed_fraction();
+    /// assert_eq!((mixed, fract), (-3, Rational::new(-1, 2)));
+    /// assert_eq!(mixed + fract, Rational::new(-7, 2));
     /// ```
     pub fn mixed_fraction(self) -> (i128, Rational) {
         let rem = self.numerator() % self.denominator();
         let whole = self.numerator() / self.denominator();
-        let mut fract = Rational::new(rem, self.denominator());
-        if whole.is_negative() && fract.is_negative() {
-            fract = -fract;
-        }
+        let fract = Rational::new(rem, self.denominator());
+        debug_assert_eq!(whole + fract, self);
         (whole, fract)
     }
 
@@ -340,15 +364,14 @@ impl Display for Rational {
 }
 
 #[cfg(test)]
+#[allow(unused)]
 mod tests {
-    #![allow(unused)]
-
     use super::*;
     use crate::extras::*;
     use rand;
     use std::collections::HashMap;
 
-    fn assert_eq_rat<Actual, Expected>(actual: Actual, expected: Expected)
+    fn assert_eq_rational<Actual, Expected>(actual: Actual, expected: Expected)
     where
         Rational: From<Actual>,
         Rational: From<Expected>,
@@ -370,30 +393,36 @@ mod tests {
 
     #[test]
     fn equality_test() {
-        assert_eq_rat((4, 8), (16, 32));
-        assert_eq_rat((2, 3), (4, 6));
+        assert_eq_rational((4, 8), (16, 32));
+        assert_eq_rational((2, 3), (4, 6));
         assert_ne_rat((-1, 2), (1, 2));
     }
 
     #[test]
     fn ctor_test() {
-        let rat = Rational::new((1, 2), (2, 4));
-        assert_eq_rat(rat, (1, 1));
+        let r = Rational::new((1, 2), (2, 4));
+        assert_eq_rational(r, (1, 1));
 
-        let rat = Rational::new((1, 2), 3);
-        assert_eq_rat(rat, (1, 6));
+        let r = Rational::new((1, 2), 3);
+        assert_eq_rational(r, (1, 6));
 
-        let rat = Rational::new((1, 2), (2, 1));
-        assert_eq_rat(rat, (1, 4));
+        let r = Rational::new((1, 2), (2, 1));
+        assert_eq_rational(r, (1, 4));
 
         let invalid = Rational::new_checked(1, 0);
         assert!(invalid.is_none());
+
+        let r = Rational::new(0, 5);
+        assert_eq_rational(r, (0, 1));
+
+        let r = Rational::new(0, -100);
+        assert_eq_rational(r, (0, 1));
     }
 
     #[test]
     fn inverse_test() {
         let inverse = Rational::new(5, 7).inverse();
-        assert_eq_rat(inverse, (7, 5));
+        assert_eq_rational(inverse, (7, 5));
 
         let invalid_inverse = Rational::new(0, 1);
         assert!(invalid_inverse.inverse_checked().is_none());
@@ -439,17 +468,6 @@ mod tests {
         assert_eq!(inverse, Rational::new(1, orig));
     }
 
-    #[test]
-    fn fuzz_test() {
-        // for _ in 0..500_000 {
-        //     let (a, b) = (random_rat(), random_rat());
-        //     assert_eq!(
-        //         a.partial_cmp(&b),
-        //         a.decimal_value().partial_cmp(&b.decimal_value())
-        //     );
-        // }
-    }
-
     #[test]
     fn set_denominator_test() {
         let mut rat = Rational::new(1, 6);
@@ -468,10 +486,12 @@ mod tests {
 
     #[test]
     fn mixed_fraction_test() {
-        let assert = |num: i128, den: i128, whole: i128, (n, d): (i128, i128)| {
+        let assert = |(num, den): (i128, i128), whole: i128, (n, d): (i128, i128)| {
             let rat = Rational::new(num, den);
             let actual_mixed_fraction = rat.mixed_fraction();
-            let expected_mixed_fraction = (whole, Rational::new(n, d));
+            let fract = Rational::new(n, d);
+            let expected_mixed_fraction = (whole, fract);
+            let sum_of_parts = whole + fract;
             assert_eq!(
                 actual_mixed_fraction,
                 (whole, Rational::new(n, d)),
@@ -479,12 +499,14 @@ mod tests {
                 num,
                 den
             );
+            assert_eq!(sum_of_parts, rat);
         };
 
-        assert(4, 3, 1, (1, 3));
-        assert(4, 4, 1, (0, 1));
-        assert(-3, 2, -1, (1, 2));
-        assert(10, 6, 1, (2, 3));
+        assert((4, 3), 1, (1, 3));
+        assert((4, 4), 1, (0, 1));
+        assert((-3, 2), -1, (-1, 2));
+        assert((10, 6), 1, (2, 3));
+        assert((0, 2), 0, (0, 1));
     }
 
     #[test]
@@ -500,6 +522,14 @@ mod tests {
         assert_eq!((-1, 5), Rational::new(2, -10).into());
     }
 
+    #[test]
+    fn pow_test() {
+        assert_eq!((1, 25), Rational::new(1, 5).pow(2).into());
+        assert_eq!((1, 9), Rational::new(2, 6).pow(2).into());
+        assert_eq!((1, 1), Rational::new(2, 6).pow(0).into());
+        assert_eq!((16, 1), Rational::new(1, 4).pow(-2).into());
+    }
+
     fn random_rat() -> Rational {
         let den = loop {
             // generate a random non-zero integer
